%	PLOT OF TEMPERATURE VARIATION INSIDE THE HUMAN EYE (POLAR)
%	Written by 	Mathew Syriac
%			St. Stephen's College, Delhi			
%			(mathewsyriac@gmail.com)
%	Completed on 	24th November 2007

clear;

%==================== PARAMETERS ====================
T2=37;		% actual temperature inside the body
T1=17;		% actual temperature in the region outside the body with which a set portion of the eye (corona) is in contact with

angle=60;	% half of the angle subtended by the corona at the center of the eye (the corona is in contact with the outside and the rest with the 			body)

divr=40;		% number of radius units. Increase for better resolution but less speed.
divt=140;		% number of theta units. Increase for better resolution but less speed.

series_n=80;	% number of terms of the infinite series upto which summing is done. Increase for greater accuracy  but less speed.

zoom=1.5;		% if set to 1, it just includes the eye. Higher values zoom out more.
view_angle=50;		% viewing angle
view_elevation=30;	% viewing elevation
%====================================================


global m;		% m will index the summation
tz=0;			% tz will be the matrix that holds the z-values (temperatures/elevations) at each point


% A function that returns the value of a Legendre Polynomial. An explicit function is required for integration using 'quad'.
function r=f(x)
	global m;
	r=legendre_Pl(m,x);
endfunction


r=linspace(0,1,divr);
theta=linspace(0,2*pi,divt);

[R,THETA]=meshgrid(r,theta);



% SOLVING LAPLACE'S EQUATION
for m=0:1:series_n

	I1=quad("f",-1,1);			% the integral of the legendre polynomial from -1 to 1
	I2=quad("f",cos(angle*pi/180),1);	% the integral of the legendre polynomial from cos(angle_rad) to 1

	am = (m.+(1./2)).*(T2.*(I1) .- ((T2.-T1).*(I2)));	% the mth coefficient in the sum
	
	tz=tz .+ (am .* (R.^m) .* f(cos(THETA)));	% the value of temperature at a given point is the sum over am*(r^m)*legendre(cos(theta))

end



% PLOT
%[x,y,Z]=pol2cart(THETA,R,tz);
%surf(x,y,Z);
%view(view_angle,view_elevation);
image(tz);
