# Simulation of an N-independent-twostate-monomer polymer                   #
#                                                                           #
#       by  John Philip Mathew                                              #
#           St.Stephen's College                                            #
#############################################################################

from visual import*
from visual.graph import*
from string import *
from random import *
#from Numeric import *
from scipy import *

scene.height=500
scene.width=960
scene.autoscale=1
scene.visible=1
   
N=100
epsilon=300     #intrinsic energy 
a=2.0           #intrinsic monomer length
kb=1.0          #otherwise k=1.38E-23
T=300.0         #temperature

#Plot display
Ldist=gdisplay(title='Length Distribution',xtitle='Length',ytitle='No of Configurations',foreground=color.black, background=color.white, height=670,width=1000)
Lbar=ghistogram(bins=arange(N*a, 2*a*N, a), color=color.red)
Edist=gdisplay(title='Energy Distribution',xtitle='Energy',ytitle='No of Configurations',foreground=color.black, background=color.white,height=670,width=1000)
Ebar=ghistogram(bins=arange(0, N*epsilon,epsilon), color=color.orange)

Monomers=[]         # list for monomer ellipsoids
LENGTH=N*2*a 
L=zeros(N)    #array to store monomer lengths
H=zeros(N)    #and array for heights
PL=zeros(N)   #and to store previous lengths and heights
PH=zeros(N)
lengthlist=[]       #to store length of each polymer configuration
energylist=[]
energy=0

#initialization
for j in range(0,N):
    Monomers=Monomers+[ellipsoid(pos=(-N+j*a,0,0),length=a,height=2*a,width=2)]
    PL[j]=a
    PH[j]=2*a
    
previousenergy=N*epsilon  #to store energy of polymer
nextenergy=0
logic=1
accept=1

while logic:
    for j in range(0,N):    #flips each monomer and checks if acceptable
        if PL[j] == a:      #flip 'a' to '2a'
            L[j]=2*a
            H[j]=a
            nextenergy=previousenergy-epsilon
        if PL[j] == 2*a:    #flip '2a' to 'a'
            L[j]=a
            H[j]=2*a
            nextenergy=previousenergy+epsilon

        if nextenergy>previousenergy:
            if uniform(0,1) < exp(-(nextenergy-previousenergy)/(kb*T)):
                accept=1
            else:
                accept=0
        else:
            accept=1
            
        if accept==1:       #state A -> B
            previousenergy=nextenergy
            PL[j]=L[j]
            PH[j]=H[j]
    
    LENGTH=0
    energy=0
    for k in range(0,N):    #displays previous accepted configuration
        Monomers[k].length=PL[k]
        Monomers[k].height=PH[k]
        LENGTH+=PL[k]
        if PL[k]==a:
            energy+=epsilon

    lengthlist.append(LENGTH)   #for graphs
    energylist.append(energy)
    Lbar.plot(data=lengthlist)
    Ebar.plot(data=energylist)

    if scene.mouse.clicked:     #to pause the run click scene
        logic=0
