###############################################
# Modification of Simon Catterall original code
# Vikram 
#################################################
from visual import *
from nbodyAcc import *

#Solar system on a computer

#Constants that we will need
#define the value of G
G=6.673e-11

sun_mass = 2e30
earth_mass = 6e24
boost=100 #allow for boosting Jupiter's mass
jupiter_mass=boost*1.9e27
#for initial conditions

AU = 149.6e9       #mean earth sun orbital distance

earth_vel = 2*math.pi * AU/(365.25 *24. *60.*60.) # average velocity = 2*Pi*R/T
jupiter_vel=2*math.pi*AU*5.2/(11.86*365.25*24.*60.*60)

#setting for animations
scene.background = color.white
scene.autoscale = 0
scene.range = 10*AU

#objects making up our solar system
sun = sphere(pos= (0,0,0), velocity = vector(0,0,0),
             mass=sun_mass, radius = 0.1*AU, color =color.yellow)
earth = sphere(pos= (AU, 0, 0), velocity = vector(0,earth_vel,0),
               mass=earth_mass, radius=0.05*AU, color =color.cyan)
jupiter=sphere(pos=(5.2*AU,0,0),velocity=vector(0,jupiter_vel,0),
             mass=jupiter_mass, radius=0.15*AU, color=color.red)

#note the radius of sun, jupiter  and earth are NOT
# their true radius these are the radius of the spherical object
#that will be draw on the computer screen.


#Create a list of objects making up our solar system 
#and add attributes for their accelaration and orbits

bodies = [sun, earth, jupiter]

for b in bodies:
    b.acc = vector(0,0,0)
    b.track=curve (color = b.color)
    
# set total momentum of system to zero (centre of mass frame) 
sum=vector(0,0,0)
for b in bodies:
    if (b!=sun):
        sum=sum+b.mass*b.velocity

sun.velocity=-sum/sun.mass

# dt corresponds to 3000 mins here
dt=30.*60.*100

#Initialize leap-frog by finding the velocites at t=dt/2

for b in bodies:
    b.velocity = b.velocity + totalacc(b, bodies)*dt/2.0

#start leap-frog
while True:
    rate(100)  #not more than 100 time steps in a second
    for b in bodies:
        #update the positions
        b.pos = b.pos + b.velocity*dt
        b.track.append(pos=b.pos)

        #update the velocities
        b.velocity = b.velocity + totalacc(b, bodies)*dt

    scene.center = sun.pos #view centered on sun
